=====================
Django Suit Dashboard
=====================

.. start-badges


|travis|
|codecov|
|landscape|
|version|
|wheel|
|pyup|
|gitter|


.. |travis| image:: https://travis-ci.org/Pawamoy/django-suit-dashboard.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/Pawamoy/django-suit-dashboard/

.. |codecov| image:: https://codecov.io/github/Pawamoy/django-suit-dashboard/coverage.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/Pawamoy/django-suit-dashboard/

.. |landscape| image:: https://landscape.io/github/Pawamoy/django-suit-dashboard/master/landscape.svg?style=flat
    :target: https://landscape.io/github/Pawamoy/django-suit-dashboard/
    :alt: Code Quality Status

.. |pyup| image:: https://pyup.io/repos/github/pawamoy/django-suit-dashboard/shield.svg
    :target: https://pyup.io/repos/github/pawamoy/django-suit-dashboard/
    :alt: Updates

.. |gitter| image:: https://badges.gitter.im/Pawamoy/django-suit-dashboard.svg
    :alt: Join the chat at https://gitter.im/Pawamoy/django-suit-dashboard
    :target: https://gitter.im/Pawamoy/django-suit-dashboard?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. |version| image:: https://img.shields.io/pypi/v/django-suit-dashboard.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/django-suit-dashboard/

.. |wheel| image:: https://img.shields.io/pypi/wheel/django-suit-dashboard.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/django-suit-dashboard/


.. end-badges

Create a dashboard within django-suit admin interface.

Screenshot
==========

.. image:: https://cloud.githubusercontent.com/assets/3999221/14685134/8cde04be-0733-11e6-8eda-b59f2e2fa6c3.png
    :alt: Screenshot

License
=======

Software licensed under `MPL 2.0`_ license.

.. _MPL 2.0 : https://www.mozilla.org/en-US/MPL/2.0/

Installation
============

::

    pip install django-suit-dashboard

Documentation
=============

https://github.com/Pawamoy/django-suit-dashboard/wiki

Development
===========

To run all the tests: ``tox``
